package com.fs.crm.service;

import java.util.List;
import com.fs.crm.domain.CrmCustomerAssist;
import com.fs.crm.param.CrmCustomerAssistDeLParam;

/**
 * 客户员工协作Service接口
 *
 * @author fs
 * @date 2025-05-27
 */
public interface ICrmCustomerAssistService
{
    /**
     * 查询客户员工协作
     *
     * @param id 客户员工协作ID
     * @return 客户员工协作
     */
    public CrmCustomerAssist selectCrmCustomerAssistById(Long id);

    /**
     * 查询客户员工协作列表
     *
     * @param crmCustomerAssist 客户员工协作
     * @return 客户员工协作集合
     */
    public List<CrmCustomerAssist> selectCrmCustomerAssistList(CrmCustomerAssist crmCustomerAssist);

    /**
     * 新增客户员工协作
     *
     * @param crmCustomerAssist 客户员工协作
     * @return 结果
     */
    public int insertCrmCustomerAssist(CrmCustomerAssist crmCustomerAssist);

    /**
     * 修改客户员工协作
     *
     * @param crmCustomerAssist 客户员工协作
     * @return 结果
     */
    public int updateCrmCustomerAssist(CrmCustomerAssist crmCustomerAssist);

    /**
     * 批量删除客户员工协作
     *
     * @param ids 需要删除的客户员工协作ID
     * @return 结果
     */
    public int deleteCrmCustomerAssistByIds(Long[] ids);

    /**
     * 删除客户员工协作信息
     *
     * @param id 客户员工协作ID
     * @return 结果
     */
    public int deleteCrmCustomerAssistById(Long id);

    int removeByCustomer(CrmCustomerAssistDeLParam param);
}
